Class: Pod::Command::Bin::Install

Inherits:
Bin
  • Object
show all
Includes:
Pod
Defined in:
lib/cocoapods-bb-bin/command/bin/install.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Pod

match_version?

Constructor Details

#initialize(argv) ⇒ Install

Returns a new instance of Install.



26
27
28
29
30
# File 'lib/cocoapods-bb-bin/command/bin/install.rb', line 26

def initialize(argv)
  @update = argv.flag?('update')
  super
  @additional_args = argv.remainder!
end

Class Method Details

.optionsObject



17
18
19
20
21
22
23
24
# File 'lib/cocoapods-bb-bin/command/bin/install.rb', line 17

def self.options
  [
    ['--repo-update', 'Force running `pod repo update` before install'],
    ['--deployment', 'Disallow any changes to the Podfile or the Podfile.lock during installation'],
    ['--clean-install', 'Ignore the contents of the project cache and force a full pod installation. This only ' \
  'applies to projects that have enabled incremental installation']
  ].concat(super).reject { |(name, _)| name == '--no-repo-update' }
end

Instance Method Details

#runObject



32
33
34
35
36
37
38
39
40
# File 'lib/cocoapods-bb-bin/command/bin/install.rb', line 32

def run
  Update.load_local_podfile
  argvs = [
    *@additional_args
  ]
  gen = Pod::Command::Install.new(CLAide::ARGV.new(argvs))
  gen.validate!
  gen.run
end